@@ -1,2 +1,2 @@
 def get_version():
-	return "0.9.11.2"
+	return "0.9.18"
